# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`rsync`](#rsync): Provides an rsync client library with a stub exec for certain edge cases
* [`rsync::selinux`](#rsync--selinux): This will configure selinux for rsync
* [`rsync::server`](#rsync--server): Sets up a fully functioning rsync server.
* [`rsync::server::global`](#rsync--server--global): Setup the global section of /etc/rsyncd.conf.  See ``rsyncd.conf(5)`` for details of parameters not listed below.

### Defined types

* [`rsync::push`](#rsync--push): This is simply a call to rsync::retrieve with $pull set to false. It's present for clarity and hopefully won't break any dependency chains if
* [`rsync::retrieve`](#rsync--retrieve): Retrieve a file over the rsync protocol
* [`rsync::server::section`](#rsync--server--section): Set up a 'section' of /etc/rsyncd.conf pertaining to a particular rsync share.  See ``rsyncd.conf(5)`` for descriptions of most variables.

### Resource types

* [`rsync`](#rsync): Run an rsync command; almost all options are directly from the rsync man page.  Though we've done what we can to mimize SELinux impact. If yo

## Classes

### <a name="rsync"></a>`rsync`

Provides an rsync client library with a stub exec for certain edge cases

#### Parameters

The following parameters are available in the `rsync` class:

* [`sebool_anon_write`](#-rsync--sebool_anon_write)
* [`sebool_client`](#-rsync--sebool_client)
* [`sebool_export_all_ro`](#-rsync--sebool_export_all_ro)
* [`sebool_full_access`](#-rsync--sebool_full_access)
* [`sebool_use_nfs`](#-rsync--sebool_use_nfs)
* [`sebool_use_cifs`](#-rsync--sebool_use_cifs)
* [`package_ensure`](#-rsync--package_ensure)

##### <a name="-rsync--sebool_anon_write"></a>`sebool_anon_write`

Data type: `Boolean`

Allow anonymous rsync users to write to shares

* Share spaces must be labeled as ``public_content_rw_t``
* Only functional if ``selinux`` is not disabled

Default value: `false`

##### <a name="-rsync--sebool_client"></a>`sebool_client`

Data type: `Boolean`

Allow rsync to act as a client

* Only functional if ``selinux`` is not disabled

Default value: `true`

##### <a name="-rsync--sebool_export_all_ro"></a>`sebool_export_all_ro`

Data type: `Boolean`

Allow rsync to export of anything on the system as read only

* Only functional if ``selinux`` is not disabled

Default value: `true`

##### <a name="-rsync--sebool_full_access"></a>`sebool_full_access`

Data type: `Boolean`

Allow rsync management of **ALL** files on the system

* Only functional if ``selinux`` is not disabled

Default value: `false`

##### <a name="-rsync--sebool_use_nfs"></a>`sebool_use_nfs`

Data type: `Boolean`

Allow rsync servers to share nfs files systems

* Only functional if ``selinux`` is not disabled
* Only applies to El6
* WARNING: Will be removed in version 7 of this module

Default value: `false`

##### <a name="-rsync--sebool_use_cifs"></a>`sebool_use_cifs`

Data type: `Boolean`

Allow rsync servers to share cifs files systems

* Only functional if ``selinux`` is not disabled
* Only applies to El6
* WARNING: Will be removed in version 7 of this module

Default value: `false`

##### <a name="-rsync--package_ensure"></a>`package_ensure`

Data type: `String`

The ensure status of the package to be managed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="rsync--selinux"></a>`rsync::selinux`

This will configure selinux for rsync

### <a name="rsync--server"></a>`rsync::server`

The main idea behind this was to work around limitations of the native Puppet
fileserving type.

Most usual options are supported, but there are far too many to tackle all of
them at once.

This mainly daemonizes rsync and keeps it running. It will also subscribe it
to the stunnel service if it has been declared.

#### Parameters

The following parameters are available in the `rsync::server` class:

* [`stunnel`](#-rsync--server--stunnel)
* [`stunnel_port`](#-rsync--server--stunnel_port)
* [`listen_address`](#-rsync--server--listen_address)
* [`drop_rsyslog_noise`](#-rsync--server--drop_rsyslog_noise)
* [`firewall`](#-rsync--server--firewall)
* [`trusted_nets`](#-rsync--server--trusted_nets)
* [`package_ensure`](#-rsync--server--package_ensure)
* [`package`](#-rsync--server--package)

##### <a name="-rsync--server--stunnel"></a>`stunnel`

Data type: `Boolean`

Use Stunnel to encrypt this connection. It is *highly* recommended to leave
this enabled.

Default value: `simplib::lookup('simp_options::stunnel', { default_value => true })`

##### <a name="-rsync--server--stunnel_port"></a>`stunnel_port`

Data type: `Simplib::Port`

The port upon which Stunnel should listen for connections.

Default value: `8730`

##### <a name="-rsync--server--listen_address"></a>`listen_address`

Data type: `Simplib::IP`

The IP Address upon which to listen. Set to 0.0.0.0 to listen on all
addresses.

Default value: `'0.0.0.0'`

##### <a name="-rsync--server--drop_rsyslog_noise"></a>`drop_rsyslog_noise`

Data type: `Boolean`

Ensure that any noise from rsync is dropped. The only items that will be
retained will be startup, shutdown, and remote connection activities.
Anything from 127.0.0.1 will be dropped as useless.

Default value: `true`

##### <a name="-rsync--server--firewall"></a>`firewall`

Data type: `Boolean`

If true, use the SIMP iptables class to manage firewall rules for this
module.

Default value: `simplib::lookup('simp_options::firewall', { default_value => false })`

##### <a name="-rsync--server--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

A list of networks and/or hostnames that are allowed to connect to this
service.

Default value: `simplib::lookup('simp_options::trusted_nets', { default_value => ['127.0.0.1'] })`

##### <a name="-rsync--server--package_ensure"></a>`package_ensure`

Data type: `String`

The ensure status of the package to be managed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="-rsync--server--package"></a>`package`

Data type: `String`

The rsync daemon package

### <a name="rsync--server--global"></a>`rsync::server::global`

Setup the global section of /etc/rsyncd.conf.

See ``rsyncd.conf(5)`` for details of parameters not listed below.

#### Parameters

The following parameters are available in the `rsync::server::global` class:

* [`motd_file`](#-rsync--server--global--motd_file)
* [`pid_file`](#-rsync--server--global--pid_file)
* [`syslog_facility`](#-rsync--server--global--syslog_facility)
* [`port`](#-rsync--server--global--port)
* [`address`](#-rsync--server--global--address)
* [`trusted_nets`](#-rsync--server--global--trusted_nets)
* [`tcpwrappers`](#-rsync--server--global--tcpwrappers)

##### <a name="-rsync--server--global--motd_file"></a>`motd_file`

Data type: `Optional[Stdlib::Absolutepath]`

The path to the default MOTD file that should be displayed upon connection

Default value: `undef`

##### <a name="-rsync--server--global--pid_file"></a>`pid_file`

Data type: `Stdlib::Absolutepath`

The path to the service PID file

Default value: `'/var/run/rsyncd.pid'`

##### <a name="-rsync--server--global--syslog_facility"></a>`syslog_facility`

Data type: `String`

A valid syslog ``facility`` to use for logging

Default value: `'daemon'`

##### <a name="-rsync--server--global--port"></a>`port`

Data type: `Simplib::Port`

The port upon which to listen for client connections

Default value: `873`

##### <a name="-rsync--server--global--address"></a>`address`

Data type: `Simplib::IP`

The IP address upon which to listen for connections

* Leave this at ``127.0.0.1`` if using stunnel

Default value: `'127.0.0.1'`

##### <a name="-rsync--server--global--trusted_nets"></a>`trusted_nets`

Data type: `Simplib::Netlist`

The networks to allow to connect to this service

Default value: `simplib::lookup('simp_options::trusted_nets', { default_value => ['127.0.0.1'] })`

##### <a name="-rsync--server--global--tcpwrappers"></a>`tcpwrappers`

Data type: `Boolean`

Use tcpwrappers to secure the rsync service

Default value: `simplib::lookup('simp_options::tcpwrappers', { default_value => false })`

## Defined types

### <a name="rsync--push"></a>`rsync::push`

This is simply a call to rsync::retrieve with $pull set to false. It's
present for clarity and hopefully won't break any dependency chains if you
use it.

See the documentation for ``rsync::retrieve`` for details.

#### Parameters

The following parameters are available in the `rsync::push` defined type:

* [`source_path`](#-rsync--push--source_path)
* [`target_path`](#-rsync--push--target_path)
* [`rsync_server`](#-rsync--push--rsync_server)
* [`proto`](#-rsync--push--proto)
* [`rsync_path`](#-rsync--push--rsync_path)
* [`preserve_perms`](#-rsync--push--preserve_perms)
* [`preserve_acl`](#-rsync--push--preserve_acl)
* [`preserve_xattrs`](#-rsync--push--preserve_xattrs)
* [`preserve_owner`](#-rsync--push--preserve_owner)
* [`preserve_group`](#-rsync--push--preserve_group)
* [`preserve_devices`](#-rsync--push--preserve_devices)
* [`exclude`](#-rsync--push--exclude)
* [`rsync_timeout`](#-rsync--push--rsync_timeout)
* [`logoutput`](#-rsync--push--logoutput)
* [`delete`](#-rsync--push--delete)
* [`bwlimit`](#-rsync--push--bwlimit)
* [`copy_links`](#-rsync--push--copy_links)
* [`size_only`](#-rsync--push--size_only)
* [`no_implied_dirs`](#-rsync--push--no_implied_dirs)
* [`user`](#-rsync--push--user)
* [`pass`](#-rsync--push--pass)
* [`rsubscribe`](#-rsync--push--rsubscribe)
* [`rnotify`](#-rsync--push--rnotify)

##### <a name="-rsync--push--source_path"></a>`source_path`

Data type: `String`



##### <a name="-rsync--push--target_path"></a>`target_path`

Data type: `String`



##### <a name="-rsync--push--rsync_server"></a>`rsync_server`

Data type: `Simplib::Host`



##### <a name="-rsync--push--proto"></a>`proto`

Data type: `String`



Default value: `'rsync'`

##### <a name="-rsync--push--rsync_path"></a>`rsync_path`

Data type: `Stdlib::Absolutepath`



Default value: `'/usr/bin/rsync'`

##### <a name="-rsync--push--preserve_perms"></a>`preserve_perms`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--preserve_acl"></a>`preserve_acl`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--preserve_xattrs"></a>`preserve_xattrs`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--preserve_owner"></a>`preserve_owner`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--preserve_group"></a>`preserve_group`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--preserve_devices"></a>`preserve_devices`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsync--push--exclude"></a>`exclude`

Data type: `Array[String]`



Default value: `['.svn/','.git/']`

##### <a name="-rsync--push--rsync_timeout"></a>`rsync_timeout`

Data type: `Integer[0]`



Default value: `2`

##### <a name="-rsync--push--logoutput"></a>`logoutput`

Data type: `Variant[Boolean,String]`



Default value: `'on_failure'`

##### <a name="-rsync--push--delete"></a>`delete`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsync--push--bwlimit"></a>`bwlimit`

Data type: `Optional[Integer[0]]`



Default value: `undef`

##### <a name="-rsync--push--copy_links"></a>`copy_links`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsync--push--size_only"></a>`size_only`

Data type: `Boolean`



Default value: `false`

##### <a name="-rsync--push--no_implied_dirs"></a>`no_implied_dirs`

Data type: `Boolean`



Default value: `true`

##### <a name="-rsync--push--user"></a>`user`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-rsync--push--pass"></a>`pass`

Data type: `Optional[String]`



Default value: `undef`

##### <a name="-rsync--push--rsubscribe"></a>`rsubscribe`

Data type: `Optional[Catalogentry]`



Default value: `undef`

##### <a name="-rsync--push--rnotify"></a>`rnotify`

Data type: `Optional[Catalogentry]`



Default value: `undef`

### <a name="rsync--retrieve"></a>`rsync::retrieve`

Retrieve a file over the rsync protocol

* **See also**
  * rsync(1)

#### Parameters

The following parameters are available in the `rsync::retrieve` defined type:

* [`source_path`](#-rsync--retrieve--source_path)
* [`target_path`](#-rsync--retrieve--target_path)
* [`rsync_server`](#-rsync--retrieve--rsync_server)
* [`proto`](#-rsync--retrieve--proto)
* [`rsync_path`](#-rsync--retrieve--rsync_path)
* [`preserve_perms`](#-rsync--retrieve--preserve_perms)
* [`preserve_acl`](#-rsync--retrieve--preserve_acl)
* [`preserve_xattrs`](#-rsync--retrieve--preserve_xattrs)
* [`preserve_owner`](#-rsync--retrieve--preserve_owner)
* [`preserve_group`](#-rsync--retrieve--preserve_group)
* [`preserve_devices`](#-rsync--retrieve--preserve_devices)
* [`exclude`](#-rsync--retrieve--exclude)
* [`rsync_timeout`](#-rsync--retrieve--rsync_timeout)
* [`logoutput`](#-rsync--retrieve--logoutput)
* [`delete`](#-rsync--retrieve--delete)
* [`bwlimit`](#-rsync--retrieve--bwlimit)
* [`copy_links`](#-rsync--retrieve--copy_links)
* [`size_only`](#-rsync--retrieve--size_only)
* [`no_implied_dirs`](#-rsync--retrieve--no_implied_dirs)
* [`user`](#-rsync--retrieve--user)
* [`pass`](#-rsync--retrieve--pass)
* [`pull`](#-rsync--retrieve--pull)
* [`rnotify`](#-rsync--retrieve--rnotify)
* [`rsubscribe`](#-rsync--retrieve--rsubscribe)

##### <a name="-rsync--retrieve--source_path"></a>`source_path`

Data type: `String`

The path *on the rsync server* from which to retrieve files

* This will, most likely, not start with a forward slash

##### <a name="-rsync--retrieve--target_path"></a>`target_path`

Data type: `String`

The path to which to write on the client system

##### <a name="-rsync--retrieve--rsync_server"></a>`rsync_server`

Data type: `Variant[Simplib::Host, Simplib::Host::Port]`

The host to which to connect

Default value: `simplib::lookup('simp_options::rsync::server')`

##### <a name="-rsync--retrieve--proto"></a>`proto`

Data type: `String`

The protocol to use

* This will go before the ``://`` in the rsync connection string
* You probably won't change this

Default value: `'rsync'`

##### <a name="-rsync--retrieve--rsync_path"></a>`rsync_path`

Data type: `Stdlib::Absolutepath`

The path to the 'rsync' command

Default value: `'/usr/bin/rsync'`

##### <a name="-rsync--retrieve--preserve_perms"></a>`preserve_perms`

Data type: `Boolean`

Preserve the file permissions from the server

Default value: `true`

##### <a name="-rsync--retrieve--preserve_acl"></a>`preserve_acl`

Data type: `Boolean`

Preserve the file ACLs from the server

Default value: `true`

##### <a name="-rsync--retrieve--preserve_xattrs"></a>`preserve_xattrs`

Data type: `Boolean`

Preserve the extended attributes from the server

Default value: `true`

##### <a name="-rsync--retrieve--preserve_owner"></a>`preserve_owner`

Data type: `Boolean`

Preserve the file owner from the server

Default value: `true`

##### <a name="-rsync--retrieve--preserve_group"></a>`preserve_group`

Data type: `Boolean`

Preserve the file group from the server

Default value: `true`

##### <a name="-rsync--retrieve--preserve_devices"></a>`preserve_devices`

Data type: `Boolean`

Preserve device special IDs from the server

Default value: `false`

##### <a name="-rsync--retrieve--exclude"></a>`exclude`

Data type: `Array[String]`

Paths and globs to exclude from transfers

Default value: `['.svn/','.git/']`

##### <a name="-rsync--retrieve--rsync_timeout"></a>`rsync_timeout`

Data type: `Integer[0]`

The number of seconds to wait for a transfer to begin before timing out

Default value: `2`

##### <a name="-rsync--retrieve--logoutput"></a>`logoutput`

Data type: `String`

Log the output of the rsync run at the provided trigger

Default value: `'on_failure'`

##### <a name="-rsync--retrieve--delete"></a>`delete`

Data type: `Boolean`

Delete local files that do not exist on the remote server

Default value: `false`

##### <a name="-rsync--retrieve--bwlimit"></a>`bwlimit`

Data type: `Optional[String]`

The bandwidth limit for the connection

Default value: `simplib::lookup('rsync::bwlimit', { 'default_value' => undef })`

##### <a name="-rsync--retrieve--copy_links"></a>`copy_links`

Data type: `Boolean`

Preserve symlinks during the transfer

Default value: `false`

##### <a name="-rsync--retrieve--size_only"></a>`size_only`

Data type: `Boolean`

Only compare files by size to determine if they need a transfer

Default value: `false`

##### <a name="-rsync--retrieve--no_implied_dirs"></a>`no_implied_dirs`

Data type: `Boolean`

Don't send implied directories with relative pathnames

Default value: `true`

##### <a name="-rsync--retrieve--user"></a>`user`

Data type: `Optional[String]`

The username to use when connecting to the server

Default value: `undef`

##### <a name="-rsync--retrieve--pass"></a>`pass`

Data type: `Optional[String]`

The password to use when connecting to the server

* If left blank, and a username is provided, the ``simplib::passgen()``
  function will be used to look up the password

Default value: `undef`

##### <a name="-rsync--retrieve--pull"></a>`pull`

Data type: `Boolean`

Pull files from the remote server

* If set to ``false``, will push files to the server instead of pulling
them from the server

Default value: `true`

##### <a name="-rsync--retrieve--rnotify"></a>`rnotify`

Data type: `Optional[Catalogentry]`

Wrap a ``notify`` so that this process will send a Puppet notification to a
resource after completion

* Use like the regular Puppet ``notify`` meta-parameter

Default value: `undef`

##### <a name="-rsync--retrieve--rsubscribe"></a>`rsubscribe`

Data type: `Optional[Catalogentry]`

Wrap a ``subscribe`` so that this process will subscribe to a Puppet
resource after completion

* Use like the regular Puppet ``subscribe`` meta-parameter

Default value: `undef`

### <a name="rsync--server--section"></a>`rsync::server::section`

Set up a 'section' of /etc/rsyncd.conf pertaining to a particular rsync share.

See ``rsyncd.conf(5)`` for descriptions of most variables.

#### Parameters

The following parameters are available in the `rsync::server::section` defined type:

* [`name`](#-rsync--server--section--name)
* [`path`](#-rsync--server--section--path)
* [`auth_users`](#-rsync--server--section--auth_users)
* [`user_pass`](#-rsync--server--section--user_pass)
* [`comment`](#-rsync--server--section--comment)
* [`use_chroot`](#-rsync--server--section--use_chroot)
* [`max_connections`](#-rsync--server--section--max_connections)
* [`max_verbosity`](#-rsync--server--section--max_verbosity)
* [`lock_file`](#-rsync--server--section--lock_file)
* [`read_only`](#-rsync--server--section--read_only)
* [`write_only`](#-rsync--server--section--write_only)
* [`list`](#-rsync--server--section--list)
* [`uid`](#-rsync--server--section--uid)
* [`gid`](#-rsync--server--section--gid)
* [`outgoing_chmod`](#-rsync--server--section--outgoing_chmod)
* [`ignore_nonreadable`](#-rsync--server--section--ignore_nonreadable)
* [`transfer_logging`](#-rsync--server--section--transfer_logging)
* [`log_format`](#-rsync--server--section--log_format)
* [`dont_compress`](#-rsync--server--section--dont_compress)
* [`hosts_allow`](#-rsync--server--section--hosts_allow)
* [`hosts_deny`](#-rsync--server--section--hosts_deny)

##### <a name="-rsync--server--section--name"></a>`name`

The arbitrary name of this configuration section

##### <a name="-rsync--server--section--path"></a>`path`

Data type: `Stdlib::Absolutepath`

The directory to make available to clients

##### <a name="-rsync--server--section--auth_users"></a>`auth_users`

Data type: `Optional[Array[String]]`

A list of usernames that are allowed to connect to this section

* ``simplib::passgen()`` will be used to generated random passwords for
  these users, if they do not already exist in the system
* Ignored if ``user_pass`` is set.

Default value: `undef`

##### <a name="-rsync--server--section--user_pass"></a>`user_pass`

Data type: `Optional[Array[String]]`

An optional array of ``username:password`` combinations to be added to the
secrets file

* Not recommended.  Instead, use ``auth_users`` to let the
  ``simplib::passgen()`` function generate your passwords
* Entries in this Array should be of the following form:
  ``username:password``

Default value: `undef`

##### <a name="-rsync--server--section--comment"></a>`comment`

Data type: `Optional[String]`

A comment for the section

Default value: `undef`

##### <a name="-rsync--server--section--use_chroot"></a>`use_chroot`

Data type: `Boolean`

Use a ``chroot`` for this service

Default value: `false`

##### <a name="-rsync--server--section--max_connections"></a>`max_connections`

Data type: `Integer[0]`

The maximum number of connections allowed

Default value: `0`

##### <a name="-rsync--server--section--max_verbosity"></a>`max_verbosity`

Data type: `Integer[0]`

The logging verbosity that the daemon should use for connections to this
service

Default value: `1`

##### <a name="-rsync--server--section--lock_file"></a>`lock_file`

Data type: `Stdlib::Absolutepath`

The path to the lock file for this service

Default value: `'/var/run/rsyncd.lock'`

##### <a name="-rsync--server--section--read_only"></a>`read_only`

Data type: `Boolean`

Do not allow clients to write to this share

Default value: `true`

##### <a name="-rsync--server--section--write_only"></a>`write_only`

Data type: `Boolean`

Only allow clients to write to this share

Default value: `false`

##### <a name="-rsync--server--section--list"></a>`list`

Data type: `Boolean`

List this share when clients ask for a list of available modules

Default value: `false`

##### <a name="-rsync--server--section--uid"></a>`uid`

Data type: `String`

The user ID that transfers should take place as

* This user must have access to all of the relevant files

Default value: `'root'`

##### <a name="-rsync--server--section--gid"></a>`gid`

Data type: `String`

The group ID that transfers should take place as

* Must have access to all of the relevant files

Default value: `'root'`

##### <a name="-rsync--server--section--outgoing_chmod"></a>`outgoing_chmod`

Data type: `String`

A symbolic ``chmod`` that will be applied to files that are transferred
outbound

Default value: `'o-w'`

##### <a name="-rsync--server--section--ignore_nonreadable"></a>`ignore_nonreadable`

Data type: `Boolean`

Completely ignore any file that is not readable by the user

Default value: `true`

##### <a name="-rsync--server--section--transfer_logging"></a>`transfer_logging`

Data type: `Boolean`

Enable per-file logging of transfers

Default value: `true`

##### <a name="-rsync--server--section--log_format"></a>`log_format`

Data type: `String`

Format used for logging file transfers when transfer logging is enabled

Default value: `"'%o %h [%a] %m (%u) %f %l'"`

##### <a name="-rsync--server--section--dont_compress"></a>`dont_compress`

Data type: `Array[String]`

Filenames and globs that should not be compressed upon transfer

Default value:

```puppet
[
    '*.gz',
    '*.tgz',
    '*.zip',
    '*.z',
    '*.rpm',
    '*.deb',
    '*.iso',
    '*.bz2',
    '*.tbz',
    '*.rar',
    '*.jar',
    '*.pdf',
    '*.sar',
    '*.war'
  ]
```

##### <a name="-rsync--server--section--hosts_allow"></a>`hosts_allow`

Data type: `Variant[Enum['*'], Simplib::Netlist]`

Hosts that should be allowed to connect to this share

* Set to ``['127.0.0.1']`` if using ``stunnel`` for the overall system
* May also be set to the String ``*`` to allow all hosts

Default value: `simplib::lookup('simp_options::trusted_nets', { 'default_value' => ['127.0.0.1'] })`

##### <a name="-rsync--server--section--hosts_deny"></a>`hosts_deny`

Data type: `Variant[Enum['*'], Simplib::Netlist]`

Hosts to explicitly deny from connection to this share

* Should be set to the String ``*`` as it is overridden by ``$hosts_allow``

Default value: `'*'`

## Resource types

### <a name="rsync"></a>`rsync`

Run an rsync command; almost all options are directly from the rsync man
page.

Though we've done what we can to mimize SELinux impact. If you have the
situation where your Puppet server's rsync space does *not* have SELinux
attributes but your client is Permissive or Enforcing. Then you will most
certainly see error messages of the type that extended attributes have
changed.

Your best bet is to ensure that your Puppet server runs in at least
Permissive mode. If you need to refresh your rsync data attributes, then
running 'fixfiles -R simp-rsync restore'.

#### Properties

The following properties are available in the `rsync` type.

##### `action`

Valid values: `push`, `pull`

Whether to push or pull from rsync server. Defaults to pull

Default value: `pull`

#### Parameters

The following parameters are available in the `rsync` type.

* [`bwlimit`](#-rsync--bwlimit)
* [`compress`](#-rsync--compress)
* [`contimeout`](#-rsync--contimeout)
* [`copy_links`](#-rsync--copy_links)
* [`delete`](#-rsync--delete)
* [`exclude`](#-rsync--exclude)
* [`hard_links`](#-rsync--hard_links)
* [`ignore_selinux`](#-rsync--ignore_selinux)
* [`iotimeout`](#-rsync--iotimeout)
* [`logoutput`](#-rsync--logoutput)
* [`name`](#-rsync--name)
* [`no_implied_dirs`](#-rsync--no_implied_dirs)
* [`pass`](#-rsync--pass)
* [`password`](#-rsync--password)
* [`path`](#-rsync--path)
* [`preserve_acl`](#-rsync--preserve_acl)
* [`preserve_devices`](#-rsync--preserve_devices)
* [`preserve_group`](#-rsync--preserve_group)
* [`preserve_owner`](#-rsync--preserve_owner)
* [`preserve_perms`](#-rsync--preserve_perms)
* [`preserve_xattrs`](#-rsync--preserve_xattrs)
* [`proto`](#-rsync--proto)
* [`protocol`](#-rsync--protocol)
* [`provider`](#-rsync--provider)
* [`recurse`](#-rsync--recurse)
* [`rsync_path`](#-rsync--rsync_path)
* [`rsync_server`](#-rsync--rsync_server)
* [`rsync_timeout`](#-rsync--rsync_timeout)
* [`server`](#-rsync--server)
* [`size_only`](#-rsync--size_only)
* [`source`](#-rsync--source)
* [`source_path`](#-rsync--source_path)
* [`target`](#-rsync--target)
* [`target_path`](#-rsync--target_path)
* [`timeout`](#-rsync--timeout)
* [`user`](#-rsync--user)

##### <a name="-rsync--bwlimit"></a>`bwlimit`

KB/s to limit I/O bandwidth to

##### <a name="-rsync--compress"></a>`compress`

Valid values: `true`, `false`

Whether or not to compress content prior to transfer. Defaults to true.

Default value: `true`

##### <a name="-rsync--contimeout"></a>`contimeout`

Connection timeout in seconds.

##### <a name="-rsync--copy_links"></a>`copy_links`

Valid values: `true`, `false`

Whether to copy links as symlinks. Defaults to false

Default value: `false`

##### <a name="-rsync--delete"></a>`delete`

Valid values: `true`, `false`

Whether to delete files that do not exist on server. Defaults to false

Default value: `false`

##### <a name="-rsync--exclude"></a>`exclude`

Exclude files matching PATTERN.  Multiple values may be specified as an
array.  Defaults to ['.svn/','.git/']

Default value: `['.svn/','.git/']`

##### <a name="-rsync--hard_links"></a>`hard_links`

Valid values: `true`, `false`

Preserve hard links. Defaults to true.

Default value: `true`

##### <a name="-rsync--ignore_selinux"></a>`ignore_selinux`

Valid values: `true`, `false`

If this is set to 'true' then this type will ignore SELinux errors. If
set to false, then an SELinux permissions copy error is a complete
failure state.

Default value: `true`

##### <a name="-rsync--iotimeout"></a>`iotimeout`

I/O timeout in seconds.

##### <a name="-rsync--logoutput"></a>`logoutput`

Valid values: `true`, `false`, `on_failure`

Whether to log output.  Defaults to logging output at the loglevel for
the `exec` resource. Use *on_failure* to only log the output when the
command reports an error.  Values are **true**, *false*, *on_failure*,
and any legal log level.

Default value: `on_failure`

##### <a name="-rsync--name"></a>`name`

namevar

The globally unique name of the resource. Has no effect on provider functionality.

##### <a name="-rsync--no_implied_dirs"></a>`no_implied_dirs`

Valid values: `true`, `false`

Do not send implied dirs.  Defaults to true

Default value: `true`

##### <a name="-rsync--pass"></a>`pass`

The password to use. Only used if a username is specified
If you want the password to be auto-generated, you can use the
SIMP 'simplib::passgen' function.

  $user = 'foo'

  rsync::retrieve { \"foo\":
    source   => 'bar',
    target   => '/tmp/foo',
    server   => 'puppet',
    user     => $user,
    password => simplib::passgen($user)
  }

##### <a name="-rsync--password"></a>`password`

The password to use. Only used if a username is specified
If you want the password to be auto-generated, you can use the
SIMP 'simplib::passgen' function.

  $user = 'foo'

  rsync::retrieve { \"foo\":
    source   => 'bar',
    target   => '/tmp/foo',
    server   => 'puppet',
    user     => $user,
    password => simplib::passgen($user)
  }

##### <a name="-rsync--path"></a>`path`

The fully qualified path to the rsync executable

##### <a name="-rsync--preserve_acl"></a>`preserve_acl`

Valid values: `true`, `false`

Whether or not to preserve ACL. Defaults to true.

Default value: `true`

##### <a name="-rsync--preserve_devices"></a>`preserve_devices`

Valid values: `true`, `false`

Whether or not to preserve device files. Defaults to false.

Default value: `false`

##### <a name="-rsync--preserve_group"></a>`preserve_group`

Valid values: `true`, `false`

Whether or not to preserve group. Defaults to true.

Default value: `true`

##### <a name="-rsync--preserve_owner"></a>`preserve_owner`

Valid values: `true`, `false`

Whether or not to preserve owner. Defaults to true.

Default value: `true`

##### <a name="-rsync--preserve_perms"></a>`preserve_perms`

Valid values: `true`, `false`

Whether or not to preserve permissions. Defaults to true.

Default value: `true`

##### <a name="-rsync--preserve_xattrs"></a>`preserve_xattrs`

Valid values: `true`, `false`

Whether or not to preserve extended attributes. Defaults to true.

Default value: `true`

##### <a name="-rsync--proto"></a>`proto`

The protocol to use in connecting to the rsync server. Defaults to "rsync"

##### <a name="-rsync--protocol"></a>`protocol`

The protocol to use in connecting to the rsync server. Defaults to "rsync"

##### <a name="-rsync--provider"></a>`provider`

The specific backend to use for this `rsync` resource. You will seldom need to specify this --- Puppet will usually
discover the appropriate provider for your platform.

##### <a name="-rsync--recurse"></a>`recurse`

Valid values: `true`, `false`

Whether or not to recursively copy. Defaults to true.

Default value: `true`

##### <a name="-rsync--rsync_path"></a>`rsync_path`

The fully qualified path to the rsync executable

##### <a name="-rsync--rsync_server"></a>`rsync_server`

The hostname or IP of the rsync server

##### <a name="-rsync--rsync_timeout"></a>`rsync_timeout`

Alias for :timeout

##### <a name="-rsync--server"></a>`server`

The hostname or IP of the rsync server

##### <a name="-rsync--size_only"></a>`size_only`

Valid values: `true`, `false`

Whether to skip files that match in size. Defaults to true

Default value: `false`

##### <a name="-rsync--source"></a>`source`

The fully qualified source path on the rsync server

##### <a name="-rsync--source_path"></a>`source_path`

The fully qualified source path on the rsync server

##### <a name="-rsync--target"></a>`target`

The fully qualified target path on the rsync client

##### <a name="-rsync--target_path"></a>`target_path`

The fully qualified target path on the rsync client

##### <a name="-rsync--timeout"></a>`timeout`

Connection timeout in seconds. Note: This is different from what the man
page states due to backward compatibility issues. Use iotimeout for the
man page compatible timeout value.

##### <a name="-rsync--user"></a>`user`

The username to use

